@@ -139,6 +139,8 @@ impl Shell for FilesystemShell {
             ));
         }
 
+        let mut hidden_dirs = vec![];
+
         // Generated stream: impl Stream<Item = Result<ReturnSuccess, ShellError>
 
         Ok(futures::stream::iter(paths.filter_map(move |path| {
@@ -147,7 +149,14 @@ impl Shell for FilesystemShell {
                 Err(err) => return Some(Err(err)),
             };
 
+            if path_contains_hidden_folder(&path, &hidden_dirs) {
+                return None;
+            }
+
             if !all && !hidden_dir_specified && is_hidden_dir(&path) {
+                if path.is_dir() {
+                    hidden_dirs.push(path);
+                }
                 return None;
             }
 
@@ -673,21 +682,56 @@ impl Shell for FilesystemShell {
         name: Span,
         with_encoding: Option<&'static Encoding>,
     ) -> Result<BoxStream<'static, Result<StringOrBinary, ShellError>>, ShellError> {
-        let f = std::fs::File::open(&path).map_err(|e| {
-            ShellError::labeled_error(
-                format!("Error opening file: {:?}", e),
-                "Error opening file",
-                name,
-            )
-        })?;
-        let async_reader = futures::io::AllowStdIo::new(f);
-        let sob_stream = FramedRead::new(async_reader, MaybeTextCodec::new(with_encoding))
-            .map_err(|e| {
-                ShellError::unexpected(format!("AsyncRead failed in open function: {:?}", e))
-            })
-            .into_stream();
+        let metadata = std::fs::metadata(&path);
 
-        Ok(sob_stream.boxed())
+        let read_full = if let Ok(metadata) = metadata {
+            // Arbitrarily capping the file at 32 megs, so we don't try to read large files in all at once
+            metadata.is_file() && metadata.len() < (1024 * 1024 * 32)
+        } else {
+            false
+        };
+
+        if read_full {
+            use futures_codec::Decoder;
+
+            // We should, in theory, be able to read in the whole file as one chunk
+            let buffer = std::fs::read(&path).map_err(|e| {
+                ShellError::labeled_error(
+                    format!("Error opening file: {:?}", e),
+                    "Error opening file",
+                    name,
+                )
+            })?;
+
+            let mut bytes_mut = bytes::BytesMut::from(&buffer[..]);
+
+            let mut codec = MaybeTextCodec::new(with_encoding);
+
+            match codec.decode(&mut bytes_mut).map_err(|e| {
+                ShellError::unexpected(format!("AsyncRead failed in open function: {:?}", e))
+            })? {
+                Some(sb) => Ok(futures::stream::iter(vec![Ok(sb)].into_iter()).boxed()),
+                None => Ok(futures::stream::iter(vec![].into_iter()).boxed()),
+            }
+        } else {
+            // We don't know that this is a finite file, so treat it as a stream
+
+            let f = std::fs::File::open(&path).map_err(|e| {
+                ShellError::labeled_error(
+                    format!("Error opening file: {:?}", e),
+                    "Error opening file",
+                    name,
+                )
+            })?;
+            let async_reader = futures::io::AllowStdIo::new(f);
+            let sob_stream = FramedRead::new(async_reader, MaybeTextCodec::new(with_encoding))
+                .map_err(|e| {
+                    ShellError::unexpected(format!("AsyncRead failed in open function: {:?}", e))
+                })
+                .into_stream();
+
+            Ok(sob_stream.boxed())
+        }
     }
 
     fn save(
@@ -751,17 +795,31 @@ fn move_file(from: TaggedPathBuf, to: TaggedPathBuf) -> Result<(), ShellError> {
         to.push(from_file_name);
     }
 
+    move_item(&from, from_tag, &to)
+}
+
+fn move_item(from: &Path, from_tag: &Tag, to: &Path) -> Result<(), ShellError> {
     // We first try a rename, which is a quick operation. If that doesn't work, we'll try a copy
-    // and remove the old file. This is necessary if we're moving across filesystems.
-    std::fs::rename(&from, &to)
-        .or_else(|_| std::fs::copy(&from, &to).and_then(|_| std::fs::remove_file(&from)))
-        .map_err(|e| {
-            ShellError::labeled_error(
+    // and remove the old file/folder. This is necessary if we're moving across filesystems or devices.
+    std::fs::rename(&from, &to).or_else(|_| {
+        match if from.is_file() {
+            let mut options = fs_extra::file::CopyOptions::new();
+            options.overwrite = true;
+            fs_extra::file::move_file(from, to, &options)
+        } else {
+            let mut options = fs_extra::dir::CopyOptions::new();
+            options.overwrite = true;
+            options.copy_inside = true;
+            fs_extra::dir::move_dir(from, to, &options)
+        } {
+            Ok(_) => Ok(()),
+            Err(e) => Err(ShellError::labeled_error(
                 format!("Could not move {:?} to {:?}. {:}", from, to, e.to_string()),
                 "could not move",
                 from_tag,
-            )
-        })
+            )),
+        }
+    })
 }
 
 fn is_empty_dir(dir: impl AsRef<Path>) -> bool {
@@ -851,8 +909,18 @@ pub(crate) fn dir_entry_dict(
         #[cfg(unix)]
         {
             for column in [
-                "name", "type", "target", "readonly", "mode", "uid", "group", "size", "created",
-                "accessed", "modified",
+                "name",
+                "type",
+                "target",
+                "num_links",
+                "readonly",
+                "mode",
+                "uid",
+                "group",
+                "size",
+                "created",
+                "accessed",
+                "modified",
             ]
             .iter()
             {
@@ -919,6 +987,9 @@ pub(crate) fn dir_entry_dict(
                     UntaggedValue::string(umask::Mode::from(mode).to_string()),
                 );
 
+                let nlinks = md.nlink();
+                dict.insert_untagged("num_links", UntaggedValue::string(nlinks.to_string()));
+
                 if let Some(user) = users::get_user_by_uid(md.uid()) {
                     dict.insert_untagged(
                         "uid",
@@ -987,3 +1058,14 @@ pub(crate) fn dir_entry_dict(
 
     Ok(dict.into_value())
 }
+
+fn path_contains_hidden_folder(path: &PathBuf, folders: &[PathBuf]) -> bool {
+    let path_str = path.to_str().expect("failed to read path");
+    if folders
+        .iter()
+        .any(|p| path_str.starts_with(&p.to_str().expect("failed to read hidden paths")))
+    {
+        return true;
+    }
+    false
+}
